@@ -30,8 +30,8 @@ MainWindow::MainWindow(QWidget *parent) :
 {
     ui->setupUi(this);
 
-    setDbScale();
-    ui->volumeBar->setValue(maxVol);
+    resetMaxValue();
+
     ui->currentVolume->setNum(0);
     ui->maximumVolume->setNum(0);
 
@@ -45,9 +45,6 @@ MainWindow::MainWindow(QWidget *parent) :
 
     connect(this, SIGNAL(updateVuMeterSignal(float)), this, SLOT(updateValues(float)), Qt::QueuedConnection);
     connect(ui->maxLabel, SIGNAL(linkActivated(QString)), this, SLOT(resetMaxValue()));
-
-    connect(ui->dBRadioButton, SIGNAL(clicked()), this, SLOT(setDbScale()));
-    connect(ui->linearRadioButton, SIGNAL(clicked()), this, SLOT(setLinearScale()));
 }
 
 MainWindow::~MainWindow()
@@ -61,20 +58,6 @@ void MainWindow::resetMaxValue(){
     ui->maximumVolume->setNum(maxVol);
 }
 
-void MainWindow::setDbScale(){
-    ui->volumeBar->setMinimum(0);
-    ui->volumeBar->setMaximum(110);
-
-    resetMaxValue();
-}
-
-void MainWindow::setLinearScale(){
-    ui->volumeBar->setMinimum(0);
-    ui->volumeBar->setMaximum(200);
-
-    resetMaxValue();
-}
-
 void MainWindow::sourceChanged(QString source){
     qDebug("New source selected: %s", source.toLocal8Bit().constData());
     disconnect_stream();
@@ -84,17 +67,14 @@ void MainWindow::sourceChanged(QString source){
 void MainWindow::updateValues(float value){
     int vol = 0;
 
-    if(ui->linearRadioButton->isChecked()){
-        vol = 100 * value;
-    }else if(ui->dBRadioButton->isChecked()){
-        vol = (int) 100 + pa_sw_volume_to_dB(pa_sw_volume_from_linear((double)value));
-    }
+    vol = (int) 100 + pa_sw_volume_to_dB(pa_sw_volume_from_linear((double)value));
 
     if(vol < 0){
         return;
     }
 
-    ui->volumeBar->setValue(vol);
+    //ui->volumeBar->setValue(vol);
+    ui->dbMeterWidget->updateValue(vol);
     ui->currentVolume->setNum(vol);
     if(maxVol < vol){
         maxVol = vol;
