@@ -48,8 +48,6 @@ private:
 
 private slots:
     void resetMaxValue();
-    void setDbScale();
-    void setLinearScale();
     void sourceChanged(QString source);
     void updateValues(float value);
 };
